﻿/**
 * @project Coveo for Sitecore
 * @Copyright (c) 2005-2018, Coveo Solutions Inc.
 */

/**
 * Handles click events for the 'Next' button in the wizard.
 * @param {Object} targetElement - The element that the old function was bound to  (i.e. the 'Next' button).
 * @param {Object} event - The original event that produced the click.
 * @returns {boolean} false at all times.
 */
function handleNextButtonNewOnClickEvent(targetElement, event) {
    var iframeElement = $('UploadCertificateFormIframe');
    var iframeContentWindow = iframeElement.contentWindow;
    var iframeDoc = iframeContentWindow.document;
    var isAdminServiceConfigurationPageVisible = isElementVisible($('AdminServiceConfigurationPage'));

    // Here's the general method that we use to handle clicks on the 'Next' button:
    // 1- We submit the form containing the certificate-related settings.
    // 2- If a validation error is displayed, we prevent the parent form containing the Admin Service settings from being submitted.
    //    If there's no error, we submit the parent form.
    // 3- If a validation error is displayed in the parent form, this means that the backend's code prevented us from passing
    //    to the next screen. If there's no error, we are allowed to pass to the next screen.

    if (isAdminServiceConfigurationPageVisible) {
        // If we have not already attached a function to the iframe's onload event handler, then we attach
        // our custom function.
        if (!iframeElement.onload) {
            iframeElement.onload = function() {
                // The onload event handler is triggered as soon as a file is uploaded/posted in the iframe.
                // We will execute the old function that was attached to the onclick event handler only if there's
                // no validation error displayed in the child iframe.
                if (!iframeContentWindow.hasErrors()) {
                    nextButtonElementOldOnClickEvent.bind(targetElement)(event);
                }
            };
        }

        // If the user is in the screen to configure the Admin Service, then we simply
        // submit the form contained in the child iframe. This will trigger the necessary validations
        // in the form.
        var uploadCertificateForm = iframeDoc.getElementsByTagName('form')[0];
        uploadCertificateForm.submit();
    } else {
        // If the user is in any other screen, we execute the old function that was attached to the onclick
        // event handler of the 'Next' button. This produces the same result as before (i.e. the parent form is submitted and
        // we pass to the next screen of the wizard).
        //
        // As a side note, the old function call looks like this: javascript:return scForm.postEvent(this,event)
        // Since 'this' in the current scope doesn't refer to the same object (i.e. the 'Next' button) that produced
        // the original onclick event, we need to replace 'this' by the correct element.
        nextButtonElementOldOnClickEvent.bind(targetElement)(event);
    }

    return false;
}

// The old function that was attached on the 'Next' button's onclick event handler.
var nextButtonElementOldOnClickEvent;

/**
 * Attaches a custom function to the onclick event handler of the 'Next' button.
 */
function toggleChangeNextButtonOnClickEvent() {
    var nextButtonElement = $('NextButton');
    if (nextButtonElementOldOnClickEvent) {
        // Revert the "onclick" event handler of the "Next" button to the old function that was attached to it.
        nextButtonElement.onclick = nextButtonElementOldOnClickEvent;
        nextButtonElementOldOnClickEvent = null;
        // Revert the "onload" event handler of the iframe to its default value.
        var iframeElement = $('UploadCertificateFormIframe');
        iframeElement.onload = null;
    } else {
        // Attach our custom function to the "onclick" event handler of the "Next" button.
        nextButtonElementOldOnClickEvent = nextButtonElement.onclick;
        nextButtonElement.onclick = function(event) {
            return handleNextButtonNewOnClickEvent(this, event);
        };
    }
}

function toggleAdminServiceSecurityMode(isSecuredConfigurationInitialisation) {
    // Display/hide the certificate configuration panel depending on the chosen security mode.
    var adminServiceCertificateConfigPanelElement = $('AdminServiceCertificateConfigPanel');
    toggleBlockElementVisibility(adminServiceCertificateConfigPanelElement);

    // Replace the scheme of the Admin Service URI, given that it's not empty and that the user changed the
    // security mode of the Admin Service.
    var adminServiceUriEditElement = $('AdminServiceUriEdit');
    var adminServiceUriEditElementOldValue = adminServiceUriEditElement.value;
    if (adminServiceUriEditElementOldValue.trim()) {
        var useSecureAdminServiceCheckboxElement = $('UseSecureAdminServiceCheckbox');
        if (!isSecuredConfigurationInitialisation) {
            if (useSecureAdminServiceCheckboxElement.checked) {
                adminServiceUriEditElement.value = adminServiceUriEditElementOldValue.replace('http://', 'https://');
            } else {
                adminServiceUriEditElement.value = adminServiceUriEditElementOldValue.replace('https://', 'http://');
            }
        }
    }
}

/**
 * Handles click events for the 'Use a secure Admin Service' checkbox in the wizard.
 */
function handleUseSecureAdminServiceCheckboxOnClickEvent() {
    toggleAdminServiceSecurityMode(false);
    toggleChangeNextButtonOnClickEvent();
}

/**
 * Attaches a new function to the onclick event handler of the 'Use a secure Admin Service' checkbox.
 */
function changeUseSecureAdminServiceCheckboxOnClickEvent() {
    $('UseSecureAdminServiceCheckbox').on('click', handleUseSecureAdminServiceCheckboxOnClickEvent);
}

// As soon as the wizard is loaded, we modify the behavior of the 'Use a secure Admin Service' checkbox
// so that we are in turn able to change the behavior of the 'Next' button in the wizard.
window.onload = function() {
    changeUseSecureAdminServiceCheckboxOnClickEvent();

    if ($('UseSecureAdminServiceCheckbox').attributes['checked'] &&
        $('UseSecureAdminServiceCheckbox').attributes['checked'].value === 'Checked') {
        toggleAdminServiceSecurityMode(true);
        toggleChangeNextButtonOnClickEvent();
    }
};